showInRoomMessageButton property
When set to true, the button for sending messages will be displayed.
If you want to disable text messaging in the live audio room, set it to false.
Implementation
bool showInRoomMessageButton;
When set to true, the button for sending messages will be displayed.
If you want to disable text messaging in the live audio room, set it to false.
bool showInRoomMessageButton;