ZegoLiveAudioRoomPIPAndroidConfig class

android pip only available on SDK higher than 26(>=26)

Constructors

ZegoLiveAudioRoomPIPAndroidConfig({Widget? background, Color? userNameTextColor, bool showUserName = true})

Properties

background Widget?
default is black
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showUserName bool
show user name or not
getter/setter pair
userNameTextColor Color?
default is white
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited