ZegoLiveAudioRoomPopUpSeatClickedMenuConfig class

pop up menu when on seat clicked

Constructors

ZegoLiveAudioRoomPopUpSeatClickedMenuConfig({List<ZegoLiveAudioRoomPopupItemValue> hiddenMenus = const [], List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo> hostExtendMenus = const [], List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo> coHostExtendMenus = const [], List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo> speakerExtendMenus = const [], List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo> audienceExtendMenus = const [], List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo> emptyExtendMenus = const []})

Properties

audienceExtendMenus List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo>
The custom menus to be displayed when the seat's user is audience.
getter/setter pair
coHostExtendMenus List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo>
The custom menus to be displayed when the seat's user is co-host.
getter/setter pair
emptyExtendMenus List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo>
The custom menus to be displayed when seat is empty.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hiddenMenus List<ZegoLiveAudioRoomPopupItemValue>
If you don't want some system menus (except cancel, customStartIndex) to appear, specify to hide them here
getter/setter pair
hostExtendMenus List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo>
The custom menus to be displayed when the seat's user is host.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerExtendMenus List<ZegoLiveAudioRoomPopUpSeatClickedMenuInfo>
The custom menus to be displayed when the seat's user is speaker.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited