ZegoLiveAudioRoomPopUpSeatClickedMenuInfo class

pop up menu info when on seat clicked

Constructors

ZegoLiveAudioRoomPopUpSeatClickedMenuInfo({required void onClicked(ZegoLiveAudioRoomPopUpSeatClickedMenuEvent event), required String title, dynamic data})

Properties

data ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onClicked ↔ void Function(ZegoLiveAudioRoomPopUpSeatClickedMenuEvent event)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited