ZegoLiveAudioRoomRole enum
User roles in the live audio room.
This enum type is used for the role property in ZegoUIKitPrebuiltLiveAudioRoomConfig.
Values
- host → const ZegoLiveAudioRoomRole
-
hostis the user with the highest authority in the live audio room. They have control over all functionalities in the room, such as disabling text chat for audience members, inviting audience members to become speakers on seats, demoting speakers to audience members, etc. - speaker → const ZegoLiveAudioRoomRole
-
speakercan engage in voice chat with the host or other speakers in the live audio room. They do not have any additional special privileges. - audience → const ZegoLiveAudioRoomRole
-
audiencecan listen to the voice chat of the host and other speakers in the live audio room, and can also send text messages.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ZegoLiveAudioRoomRole> - A constant List of the values in this enum, in order of their declaration.