ZegoLiveAudioRoomSeatConfig class

Configuration options for controlling seat behavior and style. This type is used for the seat property in ZegoUIKitPrebuiltLiveAudioRoomConfig.

Constructors

ZegoLiveAudioRoomSeatConfig({ZegoLiveAudioRoomLayoutConfig? layout, Point<double>? topLeft, Size? containerSize, ZegoLiveAudioRoomAudioVideoContainerBuilder? containerBuilder, int takeIndexWhenJoining = -1, bool canAutoSwitchOnClicked(int seatIndex)?, int takeIndexWhenAudienceRequesting(ZegoUIKitUser user)?, bool closeWhenJoining = true, List<int> hostIndexes = const [0], Image? openIcon, Image? closeIcon, bool showSoundWaveInAudioMode = true, Color? soundWaveColor, ZegoAvatarBuilder? avatarBuilder, bool keepOriginalForeground = false, ZegoAudioVideoViewForegroundBuilder? foregroundBuilder, ZegoAudioVideoViewBackgroundBuilder? backgroundBuilder, Image? hostRoleIcon, Image? coHostRoleIcon, Image? microphoneOffIcon})

Properties

avatarBuilder ↔ ZegoAvatarBuilder?
Use this to customize the avatar, and replace the default avatar with it.
getter/setter pair
backgroundBuilder ↔ ZegoAudioVideoViewBackgroundBuilder?
Use this to customize the background view of the seat, and the ZegoUIKitPrebuiltLiveAudioRoom returns the current user on the seat and the corresponding seat index.
getter/setter pair
canAutoSwitchOnClicked bool Function(int seatIndex)?
By default, the speaker will auto switch seat when click the seat that can be take on(the room is not locked the seats, and the seat is empty)
getter/setter pair
closeIcon Image?
The icon displayed for empty seats when all seats are closed (seats in the audio chat room are locked).
getter/setter pair
closeWhenJoining bool
Specifies whether to lock the seat automatically after entering the room. It only takes effect when set by the host The default value is true.
getter/setter pair
coHostRoleIcon Image?
icon for co-host
getter/setter pair
containerBuilder ZegoLiveAudioRoomAudioVideoContainerBuilder?
Custom seat container totally If you don't want to use the default seat container, you can pass a custom component through this parameter. and if return null, will be display the default view
getter/setter pair
containerSize Size?
the size of seat container
getter/setter pair
foregroundBuilder ↔ ZegoAudioVideoViewBackgroundBuilder?
Use this to customize the foreground view of the seat, and the ZegoUIKitPrebuiltLiveAudioRoom will returns the current user on the seat and the corresponding seat index.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostIndexes List<int>
Specifies the list of seats occupied by the host. Once specified, these seats can only be used by the host and cannot be occupied by speakers or audience members. The default value is [0].
getter/setter pair
hostRoleIcon Image?
icon for host
getter/setter pair
keepOriginalForeground bool
Whether to retain the original foreground
getter/setter pair
layout ZegoLiveAudioRoomLayoutConfig
The default layout of the audio chat room supports free layout with multiple rows and columns of seats. You can use this parameter to control the specific style of each row and column.
getter/setter pair
microphoneOffIcon Image?
icon when speaker's microphone off
getter/setter pair
openIcon Image?
The icon displayed for empty seats when all seats are open (seats in the audio chat room are not locked).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSoundWaveInAudioMode bool
Whether to display a wave indicator around the avatar.
getter/setter pair
soundWaveColor Color?
sound wave color
getter/setter pair
takeIndexWhenAudienceRequesting int Function(ZegoUIKitUser user)?
When the audience take on seat, do you want specify a seat? If so, return to the seat you want to specify
getter/setter pair
takeIndexWhenJoining int
Specifies the seat to occupy when joining the live audio room. This is only valid when the role is set to host or speaker.
getter/setter pair
topLeft Point<double>?
the topLeft point of seat
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited