backgroundBuilder property
ZegoAudioVideoViewBackgroundBuilder?
backgroundBuilder
getter/setter pair
Use this to customize the background view of the seat, and the ZegoUIKitPrebuiltLiveAudioRoom returns the current user on the seat and the corresponding seat index.
Implementation
ZegoAudioVideoViewBackgroundBuilder? backgroundBuilder;