canAutoSwitchOnClicked property

bool Function(int seatIndex)? canAutoSwitchOnClicked
getter/setter pair

By default, the speaker will auto switch seat when click the seat that can be take on(the room is not locked the seats, and the seat is empty)

If you don't want to switch automatically, return false.

Implementation

bool Function(int seatIndex)? canAutoSwitchOnClicked;