containerBuilder property
Custom seat container totally If you don't want to use the default seat container, you can pass a custom component through this parameter. and if return null, will be display the default view
containerBuilder = ZegoLiveAudioRoomAudioVideoContainerBuilderExtension.center()
Implementation
ZegoLiveAudioRoomAudioVideoContainerBuilder? containerBuilder;