foregroundBuilder property
ZegoAudioVideoViewBackgroundBuilder?
foregroundBuilder
getter/setter pair
Use this to customize the foreground view of the seat, and the ZegoUIKitPrebuiltLiveAudioRoom will returns the current user on the seat and the corresponding seat index.
Please note that this will overwrite the original foreground(user name, host flag, co-host flag, mic-off flag). If you want to keep the original foreground, please set keepOriginalForeground be true.
Implementation
ZegoAudioVideoViewForegroundBuilder? foregroundBuilder;