ZegoLiveAudioRoomTopMenuBarConfig class

Configuration options for the top menu bar (toolbar).

Available extensions

Constructors

ZegoLiveAudioRoomTopMenuBarConfig({List<ZegoLiveAudioRoomMenuBarButtonName> buttons = const [ZegoLiveAudioRoomMenuBarButtonName.minimizingButton, ZegoLiveAudioRoomMenuBarButtonName.leaveButton]})

Properties

buttons List<ZegoLiveAudioRoomMenuBarButtonName>
These buttons will displayed on the menu bar, order by the list only support: showMemberListButton/leaveButton/minimizingButton/pipButton
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLeaveButton bool

Available on ZegoLiveAudioRoomTopMenuBarConfig, provided by the ZegoLiveAudioRoomTopMenuBarConfigDeprecatedExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited