buttons property
These buttons will displayed on the menu bar, order by the list only support: showMemberListButton/leaveButton/minimizingButton/pipButton
Implementation
List<ZegoLiveAudioRoomMenuBarButtonName> buttons;
These buttons will displayed on the menu bar, order by the list only support: showMemberListButton/leaveButton/minimizingButton/pipButton
List<ZegoLiveAudioRoomMenuBarButtonName> buttons;