ZegoLiveAudioRoomPIPConfig class
pip config
Constructors
- ZegoLiveAudioRoomPIPConfig({int aspectWidth = 1, int aspectHeight = 1, bool enableWhenBackground = true, ZegoLiveAudioRoomPIPAndroidConfig? android})
Properties
- android ↔ ZegoLiveAudioRoomPIPAndroidConfig
-
android config
getter/setter pair
- aspectHeight ↔ int
-
aspect height
getter/setter pair
- aspectWidth ↔ int
-
aspect width
getter/setter pair
- enableWhenBackground ↔ bool
-
android: only available on SDK higher than 31(>=31)
iOS: not limit
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited